pub struct ListTopups<'a> {
pub amount: Option<RangeQuery<Timestamp>>,
pub created: Option<RangeQuery<Timestamp>>,
pub ending_before: Option<TopupId>,
pub expand: &'a [&'a str],
pub limit: Option<u64>,
pub starting_after: Option<TopupId>,
pub status: Option<TopupStatusFilter>,
}connect only.Expand description
The parameters for Topup::list.
Fields
amount: Option<RangeQuery<Timestamp>>A positive integer representing how much to transfer.
created: Option<RangeQuery<Timestamp>>A filter on the list, based on the object created field.
The value can be a string with an integer Unix timestamp, or it can be a dictionary with a number of different query options.
ending_before: Option<TopupId>A cursor for use in pagination.
ending_before is an object ID that defines your place in the list.
For instance, if you make a list request and receive 100 objects, starting with obj_bar, your subsequent call can include ending_before=obj_bar in order to fetch the previous page of the list.
expand: &'a [&'a str]Specifies which fields in the response should be expanded.
limit: Option<u64>A limit on the number of objects to be returned.
Limit can range between 1 and 100, and the default is 10.
starting_after: Option<TopupId>A cursor for use in pagination.
starting_after is an object ID that defines your place in the list.
For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include starting_after=obj_foo in order to fetch the next page of the list.
status: Option<TopupStatusFilter>Only return top-ups that have the given status.
One of canceled, failed, pending or succeeded.
Implementations
Sourceimpl<'a> ListTopups<'a>
impl<'a> ListTopups<'a>