pub struct UpdateSetupIntentPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires {
pub cb_avalgo: UpdateSetupIntentPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancairesCbAvalgo,
pub cb_exemption: Option<String>,
pub cb_score: Option<i64>,
}Fields
cb_avalgo: UpdateSetupIntentPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancairesCbAvalgoThe cryptogram calculation algorithm used by the card Issuer’s ACS to calculate the Authentication cryptogram.
Also known as cavvAlgorithm. messageExtension: CB-AVALGO.
cb_exemption: Option<String>The exemption indicator returned from Cartes Bancaires in the ARes. message extension: CB-EXEMPTION; string (4 characters) This is a 3 byte bitmap (low significant byte first and most significant bit first) that has been Base64 encoded.
cb_score: Option<i64>The risk score returned from Cartes Bancaires in the ARes. message extension: CB-SCORE; numeric value 0-99.