pub struct CreateAccountCapabilitiesBacsDebitPayments {
pub requested: Option<bool>,
}Available on crate feature
connect only.Fields
requested: Option<bool>Passing true requests the capability for the account, if it is not already requested.
A requested capability may not immediately become active.
Any requirements to activate the capability are returned in the requirements arrays.