Struct stripe::CreateAccountLink [−][src]
pub struct CreateAccountLink<'a> {
pub account: AccountId,
pub collect: Option<AccountLinkCollect>,
pub expand: &'a [&'a str],
pub refresh_url: Option<&'a str>,
pub return_url: Option<&'a str>,
pub type_: AccountLinkType,
}Expand description
The parameters for AccountLink::create.
Fields
account: AccountIdThe identifier of the account to create an account link for.
collect: Option<AccountLinkCollect>Which information the platform needs to collect from the user.
One of currently_due or eventually_due.
Default is currently_due.
expand: &'a [&'a str]Specifies which fields in the response should be expanded.
refresh_url: Option<&'a str>The URL the user will be redirected to if the account link is expired, has been previously-visited, or is otherwise invalid.
The URL you specify should attempt to generate a new account link with the same parameters used to create the original account link, then redirect the user to the new account link’s URL so they can continue with Connect Onboarding. If a new account link cannot be generated or the redirect fails you should display a useful error to the user.
return_url: Option<&'a str>The URL that the user will be redirected to upon leaving or completing the linked flow.
type_: AccountLinkTypeThe type of account link the user is requesting.
Possible values are account_onboarding or account_update.
Implementations