Struct stripe::IssuingAuthorizationRequest
source · [−]pub struct IssuingAuthorizationRequest {
pub amount: i64,
pub amount_details: Option<IssuingAuthorizationAmountDetails>,
pub approved: bool,
pub created: Timestamp,
pub currency: Currency,
pub merchant_amount: i64,
pub merchant_currency: Currency,
pub reason: IssuingAuthorizationReason,
}Fields
amount: i64The pending_request.amount at the time of the request, presented in your card’s currency and in the smallest currency unit.
Stripe held this amount from your account to fund the authorization if the request was approved.
amount_details: Option<IssuingAuthorizationAmountDetails>Detailed breakdown of amount components.
These amounts are denominated in currency and in the smallest currency unit.
approved: boolWhether this request was approved.
created: TimestampTime at which the object was created.
Measured in seconds since the Unix epoch.
currency: CurrencyThree-letter ISO currency code, in lowercase.
Must be a supported currency.
merchant_amount: i64The pending_request.merchant_amount at the time of the request, presented in the merchant_currency and in the smallest currency unit.
merchant_currency: CurrencyThe currency that was collected by the merchant and presented to the cardholder for the authorization.
Three-letter ISO currency code, in lowercase. Must be a supported currency.
reason: IssuingAuthorizationReasonThe reason for the approval or decline.