Struct stripe::IssuingCardAuthorizationControls [−][src]
pub struct IssuingCardAuthorizationControls {
pub allowed_categories: Option<Vec<MerchantCategory>>,
pub blocked_categories: Option<Vec<MerchantCategory>>,
pub spending_limits: Option<Box<Vec<IssuingCardSpendingLimit>>>,
pub spending_limits_currency: Option<Currency>,
}Fields
allowed_categories: Option<Vec<MerchantCategory>>Array of strings containing categories of authorizations to allow.
All other categories will be blocked.
Cannot be set with blocked_categories.
blocked_categories: Option<Vec<MerchantCategory>>Array of strings containing categories of authorizations to decline.
All other categories will be allowed.
Cannot be set with allowed_categories.
spending_limits: Option<Box<Vec<IssuingCardSpendingLimit>>>Limit spending with amount-based rules that apply across any cards this card replaced (i.e., its replacement_for card and that card’s replacement_for card, up the chain).
spending_limits_currency: Option<Currency>Currency of the amounts within spending_limits.
Always the same as the currency of the card.