pub struct ListCheckoutSessions<'a> {
pub created: Option<RangeQuery<Timestamp>>,
pub customer: Option<CustomerId>,
pub customer_details: Option<ListCheckoutSessionsCustomerDetails>,
pub ending_before: Option<CheckoutSessionId>,
pub expand: &'a [&'a str],
pub limit: Option<u64>,
pub payment_intent: Option<PaymentIntentId>,
pub payment_link: Option<PaymentLinkId>,
pub starting_after: Option<CheckoutSessionId>,
pub status: Option<CheckoutSessionStatus>,
pub subscription: Option<SubscriptionId>,
}checkout only.Expand description
The parameters for CheckoutSession::list.
Fields
created: Option<RangeQuery<Timestamp>>Only return the Checkout Sessions that were created during the given date interval.
customer: Option<CustomerId>Only return the Checkout Sessions for the Customer specified.
customer_details: Option<ListCheckoutSessionsCustomerDetails>Only return the Checkout Sessions for the Customer details specified.
ending_before: Option<CheckoutSessionId>A cursor for use in pagination.
ending_before is an object ID that defines your place in the list.
For instance, if you make a list request and receive 100 objects, starting with obj_bar, your subsequent call can include ending_before=obj_bar in order to fetch the previous page of the list.
expand: &'a [&'a str]Specifies which fields in the response should be expanded.
limit: Option<u64>A limit on the number of objects to be returned.
Limit can range between 1 and 100, and the default is 10.
payment_intent: Option<PaymentIntentId>Only return the Checkout Session for the PaymentIntent specified.
payment_link: Option<PaymentLinkId>Only return the Checkout Sessions for the Payment Link specified.
starting_after: Option<CheckoutSessionId>A cursor for use in pagination.
starting_after is an object ID that defines your place in the list.
For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include starting_after=obj_foo in order to fetch the next page of the list.
status: Option<CheckoutSessionStatus>Only return the Checkout Sessions matching the given status.
subscription: Option<SubscriptionId>Only return the Checkout Session for the subscription specified.
Implementations
Sourceimpl<'a> ListCheckoutSessions<'a>
impl<'a> ListCheckoutSessions<'a>