pub struct ListInvoices<'a> {
pub collection_method: Option<CollectionMethod>,
pub created: Option<RangeQuery<Timestamp>>,
pub customer: Option<CustomerId>,
pub due_date: Option<RangeQuery<Timestamp>>,
pub ending_before: Option<InvoiceId>,
pub expand: &'a [&'a str],
pub limit: Option<u64>,
pub starting_after: Option<InvoiceId>,
pub status: Option<InvoiceStatus>,
pub subscription: Option<SubscriptionId>,
}billing only.Expand description
The parameters for Invoice::list.
Fields
collection_method: Option<CollectionMethod>The collection method of the invoice to retrieve.
Either charge_automatically or send_invoice.
created: Option<RangeQuery<Timestamp>>customer: Option<CustomerId>Only return invoices for the customer specified by this customer ID.
due_date: Option<RangeQuery<Timestamp>>ending_before: Option<InvoiceId>A cursor for use in pagination.
ending_before is an object ID that defines your place in the list.
For instance, if you make a list request and receive 100 objects, starting with obj_bar, your subsequent call can include ending_before=obj_bar in order to fetch the previous page of the list.
expand: &'a [&'a str]Specifies which fields in the response should be expanded.
limit: Option<u64>A limit on the number of objects to be returned.
Limit can range between 1 and 100, and the default is 10.
starting_after: Option<InvoiceId>A cursor for use in pagination.
starting_after is an object ID that defines your place in the list.
For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include starting_after=obj_foo in order to fetch the next page of the list.
status: Option<InvoiceStatus>The status of the invoice, one of draft, open, paid, uncollectible, or void.
subscription: Option<SubscriptionId>Only return invoices for the subscription specified by this subscription ID.
Implementations
Sourceimpl<'a> ListInvoices<'a>
impl<'a> ListInvoices<'a>